==> libcamera-docs-0.5.0-2-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "libcamera", "index.html", [
    [ "libcamera API reference", "index.html", null ],
    [ "Reentrancy and Thread-Safety", "thread-safety.html", null ],
    [ "Thread Support", "thread.html", [
      [ "Threads and Objects", "thread.html#thread-objects", null ],
      [ "Threads and Signals", "thread.html#thread-signals", null ]
    ] ],
    [ "Camera Model", "camera-model.html", [
      [ "Pipeline Model", "camera-model.html#camera-pipeline-model", [
        [ "Camera Sensor Model", "camera-model.html#camera-sensor-model", null ],
        [ "Digital Zoom", "camera-model.html#digital-zoom", null ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ],
    [ "Thread Safety", "context.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"af_8h.html",
"classlibcamera_1_1CameraManager.html",
"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981",
"classlibcamera_1_1DeviceEnumerator.html#a3c539b6b75170fcf224ed5574c971842",
"classlibcamera_1_1FrameBufferAllocator.html",
"classlibcamera_1_1Matrix.html#a62740e9d1682960e5ec9ddefbb7b8cb8",
"classlibcamera_1_1PipelineHandler.html#aa82dffe399ac974ecb375cbb2a2074dd",
"classlibcamera_1_1Request_1_1Private.html#afea2b7c6a66cd3031be9fcc607e88a04",
"classlibcamera_1_1SwStatsCpu.html#a07f805ae47a24bac031894555b2c4b88",
"classlibcamera_1_1V4L2Subdevice.html#aa6c2f0770e41684df0fa0789f9f1e37f",
"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#ac9f967a7375681e18eb1c116d191519d",
"dir_4fef79e7177ba769987a8da36c892c5f.html",
"namespacelibcamera.html#a5af0e8921c435c654901a8adea02b66c",
"namespacelibcamera_1_1controls_1_1draft.html#a234649f716de8bd83bc8df1c9a1e6517",
"structlibcamera_1_1IPACameraSensorInfo.html#ab0cf3b83926392c91fd167fedd035d89",
"structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a95307069c6b0f45176b433cc128f81c0"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';

==> libcamera-docs-0.5.1-2-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "libcamera", "index.html", [
    [ "libcamera API reference", "index.html", null ],
    [ "Reentrancy and Thread-Safety", "thread-safety.html", null ],
    [ "Thread Support", "thread.html", [
      [ "Threads and Objects", "thread.html#thread-objects", null ],
      [ "Threads and Signals", "thread.html#thread-signals", null ]
    ] ],
    [ "Camera Model", "camera-model.html", [
      [ "Pipeline Model", "camera-model.html#camera-pipeline-model", [
        [ "Camera Sensor Model", "camera-model.html#camera-sensor-model", null ],
        [ "Digital Zoom", "camera-model.html#digital-zoom", null ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ],
    [ "Thread Safety", "context.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"af_8h.html",
"classlibcamera_1_1CameraManager.html",
"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981",
"classlibcamera_1_1DeviceEnumerator.html#a3c539b6b75170fcf224ed5574c971842",
"classlibcamera_1_1FrameBufferAllocator.html",
"classlibcamera_1_1Matrix.html#a8dab36799da41b19dbb85c4c3469b171",
"classlibcamera_1_1PipelineHandler.html#a6f7d619636c8988aeed3afd43ce8ed02",
"classlibcamera_1_1Request_1_1Private.html#a6d334bff3c7a4d007c94a5f08310e0a5",
"classlibcamera_1_1Stream.html#ae8b733271e2cb86da5acd9c8797ecf12",
"classlibcamera_1_1V4L2Subdevice.html#a62c91acb30f22a4b526b157c03d2cc60",
"classlibcamera_1_1ipa_1_1AwbAlgorithm.html",
"debayer_8h_source.html",
"namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295",
"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37",
"structlibcamera_1_1IPABuffer.html",
"structlibcamera_1_1ipa_1_1Pwl_1_1Interval.html#a29d5f017b92bc1df8ad0621da6665d82"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
